All Classes and Interfaces
Class
Description
A rule that controls access to an WorkMail organization.
An AWS Arn.
AssociateDelegateToResourceRequest MarshallerAssociateMemberToGroupRequest MarshallerAssumeImpersonationRoleRequest Marshaller
List all the
AvailabilityConfiguration's for the given WorkMail organization.
At least one delegate must be associated to the resource to disable automatic replies from the resource.
CancelMailboxExportJobRequest MarshallerCreateAliasRequest MarshallerCreateAvailabilityConfigurationRequest MarshallerCreateGroupRequest MarshallerCreateIdentityCenterApplicationRequest MarshallerCreateImpersonationRoleRequest MarshallerCreateMobileDeviceAccessRuleRequest MarshallerCreateOrganizationRequest MarshallerCreateResourceRequest MarshallerCreateUserRequest Marshaller
The name of the attribute, which is one of the values defined in the UserAttribute enumeration.
DeleteAccessControlRuleRequest MarshallerDeleteAliasRequest MarshallerDeleteAvailabilityConfigurationRequest MarshallerDeleteEmailMonitoringConfigurationRequest MarshallerDeleteGroupRequest MarshallerDeleteIdentityCenterApplicationRequest MarshallerDeleteIdentityProviderConfigurationRequest MarshallerDeleteImpersonationRoleRequest MarshallerDeleteMailboxPermissionsRequest MarshallerDeleteMobileDeviceAccessOverrideRequest MarshallerDeleteMobileDeviceAccessRuleRequest MarshallerDeleteOrganizationRequest MarshallerDeletePersonalAccessTokenRequest MarshallerDeleteResourceRequest MarshallerDeleteRetentionPolicyRequest MarshallerDeleteUserRequest MarshallerDeregisterFromWorkMailRequest MarshallerDeregisterMailDomainRequest MarshallerDescribeEmailMonitoringConfigurationRequest MarshallerDescribeEntityRequest MarshallerDescribeGroupRequest MarshallerDescribeIdentityProviderConfigurationRequest MarshallerDescribeInboundDmarcSettingsRequest MarshallerDescribeMailboxExportJobRequest MarshallerDescribeOrganizationRequest MarshallerDescribeResourceRequest MarshallerDescribeUserRequest Marshaller
The directory is already in use by another WorkMail organization in the same account and Region.
The directory service doesn't recognize the credentials supplied by WorkMail.
The directory is unavailable.
DisassociateDelegateFromResourceRequest MarshallerDisassociateMemberFromGroupRequest Marshaller
A DNS record uploaded to your DNS provider.
The domain to associate with an WorkMail organization.
The email address that you're trying to assign is already created for a different user, group, or resource.
Link between an endpoint property and the
AwsEndpointAttribute it represents.
The user, group, or resource that you're trying to register is already registered.
The identifier supplied for the user, group, or resource does not exist in your organization.
You are performing an operation on a user, group, or resource that isn't in the expected state, such as trying to
delete an active user.
Describes an EWS based availability provider.
The configuration applied to an organization's folders by its retention policy.
GetAccessControlEffectRequest MarshallerGetDefaultRetentionPolicyRequest MarshallerGetImpersonationRoleEffectRequest MarshallerGetImpersonationRoleRequest MarshallerGetMailboxDetailsRequest MarshallerGetMailDomainRequest MarshallerGetMobileDeviceAccessEffectRequest MarshallerGetMobileDeviceAccessOverrideRequest MarshallerGetPersonalAccessTokenMetadataRequest Marshaller
The representation of an WorkMail group.
The identifier that contains the Group ID and name of a group.
Identifiers for variables declared within the rule engine, e.g.
The IAM Identity Center configuration.
The impersonation rule that matched the input.
An impersonation role for the given WorkMail organization.
The rules for the given impersonation role.
The configuration for a resource isn't valid.
You SES configuration has customizations that WorkMail cannot save.
One or more of the input parameters don't match the service's restrictions.
The supplied password doesn't match the minimum security constraints, such as length or use of special characters.
Describes a Lambda based availability provider.
The request exceeds the limit of the resource.
ListAccessControlRulesRequest Marshaller
Represents the output for the
WorkMailClient.listAliasesPaginator(software.amazon.awssdk.services.workmail.model.ListAliasesRequest)
operation which is a paginated operation.
Represents the output for the
WorkMailAsyncClient.listAliasesPaginator(software.amazon.awssdk.services.workmail.model.ListAliasesRequest)
operation which is a paginated operation.ListAliasesRequest Marshaller
Represents the output for the
WorkMailClient.listAvailabilityConfigurationsPaginator(software.amazon.awssdk.services.workmail.model.ListAvailabilityConfigurationsRequest)
operation which is a paginated operation.
Represents the output for the
WorkMailAsyncClient.listAvailabilityConfigurationsPaginator(software.amazon.awssdk.services.workmail.model.ListAvailabilityConfigurationsRequest)
operation which is a paginated operation.ListAvailabilityConfigurationsRequest Marshaller
Represents the output for the
WorkMailClient.listGroupMembersPaginator(software.amazon.awssdk.services.workmail.model.ListGroupMembersRequest)
operation which is a paginated operation.
Represents the output for the
WorkMailAsyncClient.listGroupMembersPaginator(software.amazon.awssdk.services.workmail.model.ListGroupMembersRequest)
operation which is a paginated operation.ListGroupMembersRequest Marshaller
Filtering options for ListGroups operation.
Filtering options for ListGroupsForEntity operation.
Represents the output for the
WorkMailClient.listGroupsForEntityPaginator(software.amazon.awssdk.services.workmail.model.ListGroupsForEntityRequest)
operation which is a paginated operation.
Represents the output for the
WorkMailAsyncClient.listGroupsForEntityPaginator(software.amazon.awssdk.services.workmail.model.ListGroupsForEntityRequest)
operation which is a paginated operation.ListGroupsForEntityRequest Marshaller
Represents the output for the
WorkMailClient.listGroupsPaginator(software.amazon.awssdk.services.workmail.model.ListGroupsRequest)
operation which is a paginated operation.
Represents the output for the
WorkMailAsyncClient.listGroupsPaginator(software.amazon.awssdk.services.workmail.model.ListGroupsRequest)
operation which is a paginated operation.ListGroupsRequest Marshaller
Represents the output for the
WorkMailClient.listImpersonationRolesPaginator(software.amazon.awssdk.services.workmail.model.ListImpersonationRolesRequest)
operation which is a paginated operation.
Represents the output for the
WorkMailAsyncClient.listImpersonationRolesPaginator(software.amazon.awssdk.services.workmail.model.ListImpersonationRolesRequest)
operation which is a paginated operation.ListImpersonationRolesRequest Marshaller
Represents the output for the
WorkMailClient.listMailboxExportJobsPaginator(software.amazon.awssdk.services.workmail.model.ListMailboxExportJobsRequest)
operation which is a paginated operation.
Represents the output for the
WorkMailAsyncClient.listMailboxExportJobsPaginator(software.amazon.awssdk.services.workmail.model.ListMailboxExportJobsRequest)
operation which is a paginated operation.ListMailboxExportJobsRequest Marshaller
Represents the output for the
WorkMailClient.listMailboxPermissionsPaginator(software.amazon.awssdk.services.workmail.model.ListMailboxPermissionsRequest)
operation which is a paginated operation.
Represents the output for the
WorkMailAsyncClient.listMailboxPermissionsPaginator(software.amazon.awssdk.services.workmail.model.ListMailboxPermissionsRequest)
operation which is a paginated operation.ListMailboxPermissionsRequest Marshaller
Represents the output for the
WorkMailClient.listMailDomainsPaginator(software.amazon.awssdk.services.workmail.model.ListMailDomainsRequest)
operation which is a paginated operation.
Represents the output for the
WorkMailAsyncClient.listMailDomainsPaginator(software.amazon.awssdk.services.workmail.model.ListMailDomainsRequest)
operation which is a paginated operation.ListMailDomainsRequest Marshaller
Represents the output for the
WorkMailClient.listMobileDeviceAccessOverridesPaginator(software.amazon.awssdk.services.workmail.model.ListMobileDeviceAccessOverridesRequest)
operation which is a paginated operation.
Represents the output for the
WorkMailAsyncClient.listMobileDeviceAccessOverridesPaginator(software.amazon.awssdk.services.workmail.model.ListMobileDeviceAccessOverridesRequest)
operation which is a paginated operation.ListMobileDeviceAccessOverridesRequest MarshallerListMobileDeviceAccessRulesRequest Marshaller
Represents the output for the
WorkMailClient.listOrganizationsPaginator(software.amazon.awssdk.services.workmail.model.ListOrganizationsRequest)
operation which is a paginated operation.
Represents the output for the
WorkMailAsyncClient.listOrganizationsPaginator(software.amazon.awssdk.services.workmail.model.ListOrganizationsRequest)
operation which is a paginated operation.ListOrganizationsRequest Marshaller
Represents the output for the
WorkMailClient.listPersonalAccessTokensPaginator(software.amazon.awssdk.services.workmail.model.ListPersonalAccessTokensRequest)
operation which is a paginated operation.
Represents the output for the
WorkMailAsyncClient.listPersonalAccessTokensPaginator(software.amazon.awssdk.services.workmail.model.ListPersonalAccessTokensRequest)
operation which is a paginated operation.ListPersonalAccessTokensRequest Marshaller
Represents the output for the
WorkMailClient.listResourceDelegatesPaginator(software.amazon.awssdk.services.workmail.model.ListResourceDelegatesRequest)
operation which is a paginated operation.
Represents the output for the
WorkMailAsyncClient.listResourceDelegatesPaginator(software.amazon.awssdk.services.workmail.model.ListResourceDelegatesRequest)
operation which is a paginated operation.ListResourceDelegatesRequest Marshaller
Filtering options for ListResources operation.
Represents the output for the
WorkMailClient.listResourcesPaginator(software.amazon.awssdk.services.workmail.model.ListResourcesRequest)
operation which is a paginated operation.
Represents the output for the
WorkMailAsyncClient.listResourcesPaginator(software.amazon.awssdk.services.workmail.model.ListResourcesRequest)
operation which is a paginated operation.ListResourcesRequest MarshallerListTagsForResourceRequest Marshaller
Filtering options for ListUsers operation.
Represents the output for the
WorkMailClient.listUsersPaginator(software.amazon.awssdk.services.workmail.model.ListUsersRequest)
operation which is a paginated operation.
Represents the output for the
WorkMailAsyncClient.listUsersPaginator(software.amazon.awssdk.services.workmail.model.ListUsersRequest)
operation which is a paginated operation.ListUsersRequest Marshaller
The details of a mailbox export job, including the user or resource ID associated with the mailbox and the S3 bucket
that the mailbox contents are exported to.
The domain you're trying to change is in use by another user or organization in your account.
The domain specified is not found in your organization.
After a domain has been added to the organization, it must be verified.
The data for a given domain.
The representation of a user or group.
The rule that a simulated user matches.
The override object.
A rule that controls access to mobile devices for an WorkMail group.
The user, group, or resource name isn't unique in WorkMail.
An operation received a valid organization identifier that either doesn't belong or exist in the system.
The organization must have a valid state to perform certain operations on the organization or its members.
The representation of an organization.
Permission granted to a user, group, or resource to access a certain aspect of another user, group, or resource
mailbox.
Displays the Personal Access Token status.
The summary of the Personal Access Token.
PutAccessControlRuleRequest MarshallerPutEmailMonitoringConfigurationRequest MarshallerPutIdentityProviderConfigurationRequest MarshallerPutInboundDmarcSettingsRequest MarshallerPutMailboxPermissionsRequest MarshallerPutMobileDeviceAccessOverrideRequest MarshallerPutRetentionPolicyRequest Marshaller
Describes an EWS based availability provider when returned from the service.
RegisterMailDomainRequest MarshallerRegisterToWorkMailRequest Marshaller
This user, group, or resource name is not allowed in WorkMail.
ResetPasswordRequest Marshaller
The representation of a resource.
The resource cannot be found.
Represents a URL to be used internally for endpoint resolution.
StartMailboxExportJobRequest Marshaller
Describes a tag applied to a resource.
TagResourceRequest MarshallerTestAvailabilityConfigurationRequest Marshaller
The resource can have up to 50 user-applied tags.
You can't perform a write operation against a read-only directory.
UntagResourceRequest MarshallerUpdateAvailabilityConfigurationRequest MarshallerUpdateDefaultMailDomainRequest MarshallerUpdateGroupRequest MarshallerUpdateImpersonationRoleRequest MarshallerUpdateMailboxQuotaRequest MarshallerUpdateMobileDeviceAccessRuleRequest MarshallerUpdatePrimaryEmailAddressRequest MarshallerUpdateResourceRequest MarshallerUpdateUserRequest Marshaller
The representation of an WorkMail user.
Base class for the types of values computable by the
RuleEngine.An array value.
A boolean value.
An integer value.
A record (map) value.
A string value.
Service client for accessing Amazon WorkMail asynchronously.
A builder for creating an instance of
WorkMailAsyncClient.The parameters object used to resolve the auth schemes for the WorkMail service.
A builder for a
WorkMailAuthSchemeParams.An auth scheme provider for WorkMail service.
This includes configuration specific to Amazon WorkMail that is supported by both
WorkMailClientBuilder and
WorkMailAsyncClientBuilder.Service client for accessing Amazon WorkMail.
A builder for creating an instance of
WorkMailClient.The parameters object used to resolve an endpoint for the WorkMail service.
An endpoint provider for WorkMail.
Class to expose the service client settings to the user.
A builder for creating a
WorkMailServiceClientConfiguration